#[cfg(test)]
mod thread {
    use std::sync::mpsc::channel;
    use std::sync::Arc;
    use std::sync::Mutex;
    use std::thread;
    use std::time::Duration;

    #[test]
    fn test_thread() {
        let handle = thread::spawn(move || {
            thread::sleep(Duration::from_millis(500));
        });

        handle.join().unwrap();
    }

    #[test]
    fn test_channel() {
        let (tx, rx) = channel();
        for i in 0..10 {
            let tx = tx.clone();
            thread::spawn(move || {
                tx.send(i).unwrap();
            });
        }

        for _ in 0..10 {
            let j = rx.recv().unwrap();
            assert!(0 <= j && j < 10);
        }
    }

    #[test]
    fn test_mutex() {
        let value = Arc::new(Mutex::new(vec![2, 4, 6]));
        let cloned = Arc::clone(&value);

        let handle = thread::spawn(move || {
            let mut value = cloned.lock().unwrap();
            value.push(135);
        });
        handle.join().unwrap();

        println!("{:?}", *value.lock().unwrap());
    }
}
